/*
 * Copyright 2014 Peter Olsson
 * 
 * This file is part of Brum Brum Rally.
 * 
 * Brum Brum Rally is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Brum Brum Rally is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GAMELIST_H
#define GAMELIST_H

#include <vector>
#include "SDL_net.h"
#include "RenderObject.h"
#include "MenuText.h"

struct NetworkGameInfo;
class GameState;

class GameList
{
public:
	GameList();
	void update(const IPaddress& address, const NetworkGameInfo* gameInfo);
	IPaddress onEvent(const SDL_Event& event);
	void setGameState(GameState* gameState);
	void focus(bool focusValue);
	bool focus();
private:
	struct Game
	{
		IPaddress address;
		RenderObject* renderObject;
		std::string text[5];
	};
	void updateRenderObject(std::size_t i);
	void updateRenderObjects();
	void updateUpArrow(bool arrowHover, bool arrowVisible);
	void updateDownArrow(bool arrowHover, bool arrowVisible);
	void next();
	void prev();
	bool scrollDown();
	bool scrollUp();
	void mouseMove(int x, int y);
	void click(int x, int y, IPaddress& joinAddress);
	std::vector<Game> games;
	bool selected;
	std::size_t iGame;
	std::size_t scrollPos;
	GameState* gameState;
	bool hasFocus;
	int hoverGame;
	
	RenderObject upArrow;
	bool upArrowHover;
	bool upArrowVisible;
	
	RenderObject downArrow;
	bool downArrowHover;
	bool downArrowVisible;
	MenuText noGamesText;
};

#endif
